import argparse


def print_args(line_limit=80):
  print("-" * 80)

  global args
  options = vars(args)

  for opt in options:
    value = options[opt]
    log_string = str(opt)
    log_string += "." * (line_limit - len(str(opt)) - len(str(value)))
    log_string += str(value)
    print(log_string, flush=True)

  print("-" * 80)


parser = argparse.ArgumentParser()

# distrituted params
parser.add_argument("-s", "--size", type=int, # can change to a list
                    default=8, help="number of nodes")
parser.add_argument("-m", "--master_addr", default=None,
                    help="param server address")
parser.add_argument("-p", "--master_port", type=int, help="param server port")

# training hyper params
parser.add_argument("-t", "--n_trials", type=int, default=1,
                    help="number of trials")
parser.add_argument("-nb", "--n_batches", type=int, default=3,
                    help="num batches for each node, use this")
parser.add_argument("-b", "--batch_size", type=int,
                    default=128, help="batch size, optional, edit code to use this")
parser.add_argument("-lr", "--learning_rate", default='1e-3',
                    type=float, help="learning rate")
parser.add_argument("-l2", "--l2_reg", type=float, default='1e-2',
                    help="l2 regularization")
parser.add_argument("-e", "--n_epochs", default=30,
                    type=int, help="num epochs")
parser.add_argument("-inner", "--n_inner_loops", type=int, default=4,
                    help="number of inner loops for svrg/adaptive algorithms")

# model and data
# NOTE: see init_model() and adjust to your need
parser.add_argument("-model", "--model_type", default='regression',
                    help="model type, e.g. regression, classification, ...")
parser.add_argument("-d", "--dataset", default='mnist',
                    choices=['mnist', 'cifar10', 'abalone'],
                    help="dataset")

# those are the same stored init weights, to make the init loss the same for
# all model being tested
parser.add_argument("-mc", "--mnist_convex_weights",
                    default='../weights/mnist_convex',
                    help="path to mnist convex weights")
parser.add_argument("-mn", "--mnist_cnn_weights",
                    default='../weights/mnist_cnn',
                    help="path to mnist cnn weights")
parser.add_argument("-cc", "--cifar10_convex_weights",
                    default='../weights/cifar10_convex',
                    help="path to cifar10 convex weights")
parser.add_argument("-cn", "--cifar10_cnn_weights",
                    default='../weights/cifar10_cnn',
                    help="path to ciafr10 cnn weights")
parser.add_argument("-ar", "--abalone_regression_weights",
                    default='../weights/abalone_regression_weights',
                    help="path to abalone regression weights")

# skewed data - optional for additional explorations
parser.add_argument("-sk", "--is_skewed", type=int, choices=[0, 1],
                    default=0, help="data is skewed by nodes or not")

args = parser.parse_args()
# print_args(80)




