#!/usr/bin/env python

import numpy as np
import random
import torch

from time import time
from torch.multiprocessing import Process

# local imports
from config import args, print_args
from d_sgd import dsgd
from d_svrg import dsvrg
from utils import init_processes


if __name__ == "__main__":
  random_seed = 54334
  np.random.seed(random_seed + 1)
  torch.manual_seed(random_seed + 2)
  random.seed(random_seed + 3)

  print_args()

  processes = []
  # for size in sizes: # if sizes is a list then use this and indent the rest
  for target_fn in [
                    dsgd,
                    dsvrg,
                    ]:
    for i in range(args.n_trials):
      start = time()
      for rank in range(args.size):
        p = Process(target=init_processes,
                    args=(rank, args.size, target_fn,
                          'gloo',
                          args.master_addr, args.master_port))
        p.start()
        processes.append(p)

      for p in processes:
        p.join()

      cost = time() - start
      print("TEST TAKES: {} seconds".format(cost))